``vbeam`` core
--------------

.. automodule::
    vbeam.core

Modules
=======

.. autosummary::
    :toctree: _autosummary
    :template: core-module-template.rst
    :recursive:
    
    ~vbeam.core.kernels
    ~vbeam.core.wavefront
    ~vbeam.core.apodization
    ~vbeam.core.element_geometry
    ~vbeam.core.wave_data
    ~vbeam.core.speed_of_sound
    ~vbeam.core.interpolation
    ~vbeam.core.kernel_data
